@@ -1,6 +1,7 @@
 import re
 import os
 import os.path
+import math
 import numpy as np
 from eloquentarduino.utils.misc import is_list
 from jinja2 import Environment, FileSystemLoader, BaseLoader
@@ -15,6 +16,15 @@ class CustomEnvironment(Environment):
         return os.path.normpath(os.path.join(os.path.dirname(parent), template))
 
 
+class CustomLoader(FileSystemLoader):
+    """
+    Make compatible with Windows and Unix
+    """
+    def get_source(self, environment, template):
+        template = template.replace(os.path.sep, '/')
+        return super().get_source(environment, template)
+
+
 def shape(arr):
     """
     Convert array shape to C
@@ -50,6 +60,8 @@ def jinja_env(loader):
     env = CustomEnvironment(loader=loader)
     env.filters['shape'] = shape
     env.filters['to_array'] = to_array
+    env.filters['ceil'] = math.ceil
+    env.filters['floor'] = math.floor
     env.globals['np'] = np
     env.globals['enumerate'] = enumerate
     env.globals['isinstance'] = isinstance
@@ -111,7 +123,8 @@ def jinja(template_name, template_data={}, pretty=False):
     )
 
     dir_path = os.path.dirname(os.path.realpath(__file__))
-    loader = FileSystemLoader(os.path.join(dir_path, '..', 'templates'))
+    #loader = FileSystemLoader(os.path.join(dir_path, '..', 'templates'))
+    loader = CustomLoader(os.path.join(dir_path, '..', 'templates'))
     template = jinja_env(loader=loader).get_template(template_name)
     output = template.render(template_data)
 
